@@ -1,11 +1,29 @@
 import requests
 
 
-# we implement this as a generator, since this allows
-# us to cancel the download. This is particular usefull
-# when this function is run in a worker thread.
 def download_file(url, path, status_callback, chunk_size=4096):
+    """download a file from an url and save it to a path.
 
+        we implement this as a generator, since this allows
+        us to cancel the download. This is particular usefull
+        when this function is run in a worker thread.
+
+    Parameters
+    ----------
+    url : TYPE
+        Description
+    path : TYPE
+        Description
+    status_callback : TYPE
+        Description
+    chunk_size : int, optional
+        Description
+
+    Yields
+    ------
+    TYPE
+        Description
+    """
     chunks = []
 
     response = requests.get(url, stream=True)
