@@ -17,18 +17,24 @@ class RotatingLabel(QtWidgets.QLabel):
         self.setPixmap(self._pixmap)
 
     def rotate(self, value):
+
+        # store withd/height
+        # before rotating
+        pxw = int(self._pixmap.width())
+        pxh = int(self._pixmap.height())
+
+        # rotate the pixmap
         t = QtGui.QTransform()
         t.rotate(value)
-
-        pxw = self._pixmap.width()
-        pxh = self._pixmap.height()
-
         pix = self._pixmap.transformed(t)
 
+        # crop an image from the center with the size before
+        # rotating st. the image will keep the same size
         pix = pix.copy(
             (pix.width() - pxw) // 2, (pix.height() - pxh) // 2, pxw, pxh
         )
 
+        # update the pixmap
         self.setPixmap(pix)
 
 
@@ -44,5 +50,14 @@ class RotatingLogoWidget(QtWidgets.QWidget):
         lay.addWidget(self.label)
 
     def setValue(self, v):
-        deg = -3.6 * v * 4
-        self.label.rotate(deg)
+        # how often shall we rotate
+        # when hitting 100%
+        n_rotations_on_100_percent = 5
+
+        # convert v (in range from [0,100])
+        # to degrees (in range from [0,360])
+        deg = -3.6 * v
+
+        # the actual number of degrees we need to rotate
+        effective_deg = deg * n_rotations_on_100_percent
+        self.label.rotate(effective_deg)
